==> capture-error-log-1.0.8.tgz: package/src/index.js <==
class Log {
  constructor (config = {}) {
    this.config = config
    this._window = config.window
    this.needIntercept = true
    if (this.config.interceptDomain) {
      this.needIntercept = this._window.location.origin.includes(this.config.interceptDomain)
    }
    this.init()
  }
  init () {
    this.windowError()
    this.resourceError()
    this.Console()
    this.needIntercept && this.ajaxError()
  }
  windowError () {
    let that = this
    if (that.config.Vue && that.config.Vue.config) {
      const Vue = that.config.Vue
      Vue.config.errorHandler = function (err, vm, info) {
        console.error(1213, err.line, err.col, err.msg, err.stack)
        that.needIntercept && that.config.sendError({
          title: 'vue Error',
          msg: JSON.stringify(err.stack),
          url: that._window.location.href,
          type: 'js'
        })
      }
    }
    that._window.onerror = function (msg, url, line, col, error) {
      console.error(msg, url, line, col, error)
      if (error && error.stack) {
        that.needIntercept && that.config.sendError({
          title: msg,
          msg: JSON.stringify(error.stack),
          url: that._window.location.href,
          type: 'js'
        })
      } else if (typeof msg === 'string') {
        that.needIntercept && that.config.sendError({
          title: msg,
          msg: JSON.stringify(msg),
          url: that._window.location.href,
          type: 'js'
        })
      }
    }

  }
  resourceError () {
    let that = this
    that._window.addEventListener('error', function (event) {
      if (event) {
        let target = event.target || event.srcElement
        let isElementTarget = target instanceof HTMLScriptElement || target instanceof HTMLImageElement || target instanceof HTMLLinkElement

        if (!isElementTarget) return false

        that.needIntercept && that.config.sendError({
          title: target.nodeName,
          msg: target.outerHTML,
          url: that._window.location.href,
          type: 'resource'
        })
      }
    }, true)
  }
  ajaxError () {
    let that = this
    interceptAjax(that, {
      open: function (arg, xhr){
        this.ajaxObj.type = arg[0]
        this.ajaxObj.url = arg[1]
        this.ajaxObj.async = arg[2]
        this.ajaxObj.responseTime = (new Date()).getTime()
      },
      send: function (arg, xhr) {
        let type = this.ajaxObj.type
        if (type === 'POST') {
          try {
            this.ajaxObj.data = JSON.parse(arg[0] || null)
          } catch (e) {
            this.ajaxObj.data = {}
          }

        } else {
          try {
            let url = this.ajaxObj.url
            let params = url.slice(url.indexOf('?') + 1)
            let data = {}
            params.split('&').forEach(item => {
              let v = item.split('=')
              data[v[0]] = v[1]
            })
            this.ajaxObj.data = data
          } catch (e) {
            this.ajaxObj.data = {}
          }

        }
      },
      onreadystatechange: function (res) {
        xhrOnloadFn(res)
      },
      onload: function (res) {
        xhrOnloadFn(res)
      }
    })
    function xhrOnloadFn (res) {
      let xhr = res.xhr
      if (xhr && xhr.readyState === 4) {
        res.ajaxObj.status = xhr.status
        res.ajaxObj.responseURL = xhr.responseURL || ''
        res.ajaxObj.responseHeaders = res.getAllResponseHeaders()
        res.ajaxObj.responseTime = (new Date()).getTime() - res.ajaxObj.responseTime
        try {
          res.ajaxObj.response = JSON.parse(xhr.response) || JSON.parse(xhr.responseText)
        } catch (e) {
          res.ajaxObj.response = xhr.response || xhr.responseText
        }

        let filterUrl = that.config.filterHttpUrl || []
        let hasAbort = false

        if (typeof filterUrl === 'string') {
          hasAbort = res.ajaxObj.responseURL.includes(filterUrl)
        } else {
          filterUrl.forEach(item => {
            if (res.ajaxObj.url.includes(item)) {
              hasAbort = true
            }
          })
        }

        if (!hasAbort) {
          that.needIntercept && that.config.sendError({
            title: 'ajaxMsg',
            msg: JSON.stringify(res.ajaxObj),
            url: that._window.location.href,
            type: 'ajax'
          })
        }
      }
    }
  }
  Console () {
    const that = this
    const _window = that._window
    let consoleLog = _window.console.log
    if (consoleLog) {
      _window.log = function () {
        if (that.needIntercept) {
          consoleLog.apply(_window, arguments)
          that.config.sendError({
            title: 'consoleLog',
            msg: JSON.stringify([...arguments]),
            url: that._window.location.href,
            type: 'console'
          })
        }
      }
    }
  }
}

export const interceptAjax = function (that, proxy) {
  that._window._privatexhr = that._window._privatexhr || XMLHttpRequest
  XMLHttpRequest = function () {
    this.xhr = new that._window._privatexhr()
    this.ajaxObj = {}
    for (let attr in this.xhr) {
      let type = typeof this.xhr[attr]
      if (type === 'function') {
        this[attr] = interceptFun(attr)
      } else {
        Object.defineProperty(this, attr, {
          get: getIntercept(attr),
          set: setIntercept(attr)
        })
      }
    }
  }

  function getIntercept(attr) {
    return function () {
      var v= this.hasOwnProperty(attr + "_")?this[attr + "_"]:this.xhr[attr];
      var attrGetterHook=(proxy[attr]||{})["getter"]
      return attrGetterHook&&attrGetterHook(v,this)||v
    }
  }

  function setIntercept(attr) {
    return function (v) {
      var xhr = this.xhr;
      var that = this;
      var hook=proxy[attr];
      if (typeof hook==="function") {
        xhr[attr] = function () {
          proxy[attr](that) || v.apply(xhr, arguments);
        }
      }
    }
  }

  function interceptFun (fun) {
    return function () {
      const args = [].slice.call(arguments)
      if (proxy[fun] && proxy[fun].call(this, args, this.xhr)) return false
      return this.xhr[fun].apply(this.xhr, args)
    }
  }
}

export default Log

==> capture-error-log-1.0.9.tgz: package/src/index.js <==
class Log {
  constructor (config = {}) {
    this.config = config
    this._window = config.window
    this.needIntercept = true
    if (this.config.interceptDomain) {
      this.needIntercept = this._window.location.origin.includes(this.config.interceptDomain)
    }
    this.init()
  }
  init () {
    this.windowError()
    this.resourceError()
    this.Console()
    this.needIntercept && this.ajaxError()
  }
  windowError () {
    let that = this
    if (that.config.Vue && that.config.Vue.config) {
      const Vue = that.config.Vue
      Vue.config.errorHandler = function (err, vm, info) {
        console.error(1213, err.line, err.col, err.msg, err.stack)
        that.needIntercept && that.config.sendError({
          title: 'vue Error',
          msg: JSON.stringify(err.stack),
          url: that._window.location.href,
          type: 'js'
        })
      }
    }
    that._window.onerror = function (msg, url, line, col, error) {
      console.error(msg, url, line, col, error)
      if (error && error.stack) {
        that.needIntercept && that.config.sendError({
          title: msg,
          msg: JSON.stringify(error.stack),
          url: that._window.location.href,
          type: 'js'
        })
      } else if (typeof msg === 'string') {
        that.needIntercept && that.config.sendError({
          title: msg,
          msg: JSON.stringify(msg),
          url: that._window.location.href,
          type: 'js'
        })
      }
    }

  }
  resourceError () {
    let that = this
    that._window.addEventListener('error', function (event) {
      if (event) {
        let target = event.target || event.srcElement
        let isElementTarget = target instanceof HTMLScriptElement || target instanceof HTMLImageElement || target instanceof HTMLLinkElement

        if (!isElementTarget) return false

        that.needIntercept && that.config.sendError({
          title: target.nodeName,
          msg: target.outerHTML,
          url: that._window.location.href,
          type: 'resource'
        })
      }
    }, true)
  }
  ajaxError () {
    let that = this
    interceptAjax(that, {
      open: function (arg, xhr){
        this.ajaxObj.type = arg[0]
        this.ajaxObj.url = arg[1]
        this.ajaxObj.async = arg[2]
        this.ajaxObj.responseTime = (new Date()).getTime()
      },
      send: function (arg, xhr) {
        let type = this.ajaxObj.type
        if (type === 'POST') {
          try {
            this.ajaxObj.data = JSON.parse(arg[0] || null)
          } catch (e) {
            this.ajaxObj.data = {}
          }

        } else {
          try {
            let url = this.ajaxObj.url
            let params = url.slice(url.indexOf('?') + 1)
            let data = {}
            params.split('&').forEach(item => {
              let v = item.split('=')
              data[v[0]] = v[1]
            })
            this.ajaxObj.data = data
          } catch (e) {
            this.ajaxObj.data = {}
          }

        }
      },
      onreadystatechange: function (res) {
        xhrOnloadFn(res)
      },
      onload: function (res) {
        xhrOnloadFn(res)
      }
    })
    function xhrOnloadFn (res) {
      let xhr = res.xhr
      if (xhr && xhr.readyState === 4) {
        res.ajaxObj.status = xhr.status
        res.ajaxObj.responseURL = xhr.responseURL || ''
        res.ajaxObj.responseHeaders = res.getAllResponseHeaders()
        res.ajaxObj.responseTime = (new Date()).getTime() - res.ajaxObj.responseTime
        try {
          res.ajaxObj.response = JSON.parse(xhr.response) || JSON.parse(xhr.responseText)
        } catch (e) {
          res.ajaxObj.response = xhr.response || xhr.responseText
        }

        let filterUrl = that.config.filterHttpUrl || []
        let hasAbort = false

        if (typeof filterUrl === 'string') {
          hasAbort = res.ajaxObj.responseURL.includes(filterUrl)
        } else {
          filterUrl.forEach(item => {
            if (res.ajaxObj.url.includes(item)) {
              hasAbort = true
            }
          })
        }

        if (!hasAbort) {
          that.needIntercept && that.config.sendError({
            title: 'ajaxMsg',
            msg: JSON.stringify(res.ajaxObj),
            url: that._window.location.href,
            type: 'ajax'
          })
        }
      }
    }
  }
  Console () {
    const that = this
    const _window = that._window
    let consoleLog = _window.console.log
    if (consoleLog) {
      _window.captureLog = function () {
        if (that.needIntercept) {
          consoleLog.apply(_window, arguments)
          that.config.sendError({
            title: 'consoleLog',
            msg: JSON.stringify([...arguments]),
            url: that._window.location.href,
            type: 'console'
          })
        }
      }
    }
  }
}

export const interceptAjax = function (that, proxy) {
  that._window._privatexhr = that._window._privatexhr || XMLHttpRequest
  XMLHttpRequest = function () {
    this.xhr = new that._window._privatexhr()
    this.ajaxObj = {}
    for (let attr in this.xhr) {
      let type = typeof this.xhr[attr]
      if (type === 'function') {
        this[attr] = interceptFun(attr)
      } else {
        Object.defineProperty(this, attr, {
          get: getIntercept(attr),
          set: setIntercept(attr)
        })
      }
    }
  }

  function getIntercept(attr) {
    return function () {
      var v= this.hasOwnProperty(attr + "_")?this[attr + "_"]:this.xhr[attr];
      var attrGetterHook=(proxy[attr]||{})["getter"]
      return attrGetterHook&&attrGetterHook(v,this)||v
    }
  }

  function setIntercept(attr) {
    return function (v) {
      var xhr = this.xhr;
      var that = this;
      var hook=proxy[attr];
      if (typeof hook==="function") {
        xhr[attr] = function () {
          proxy[attr](that) || v.apply(xhr, arguments);
        }
      }
    }
  }

  function interceptFun (fun) {
    return function () {
      const args = [].slice.call(arguments)
      if (proxy[fun] && proxy[fun].call(this, args, this.xhr)) return false
      return this.xhr[fun].apply(this.xhr, args)
    }
  }
}

export default Log
